run_cargo_project

Function run_cargo_project 

pub fn run_cargo_project(
    project_dir: &Path,
    extra_args: &[String],
) -> Result<(), String>
Runs an existing Cargo project directory with cargo run.

If the project has no dependencies (empty [dependencies] or none at all), the interpreter could be used, but we always delegate to cargo for full compatibility with the project’s build configuration, build scripts, proc macros, multiple source files, modules, etc.