Method dispatch for built-in types.
Each section handles methods for a specific value type: String, Array/Vec, Int, Float, Char, Bool, Option.
Method dispatch for built-in types.
Each section handles methods for a specific value type: String, Array/Vec, Int, Float, Char, Bool, Option.