Value

Enum Value 

pub enum Value {
Show 15 variants Int(i64), Float(f64), Bool(bool), Char(char), String(String), Array(Vec<Value>), Tuple(Vec<Value>), Struct { name: String, fields: HashMap<String, Value>, }, Function { name: String, params: Vec<(String, Type)>, body: Box<Expr>, closure_env: Option<Environment>, }, Closure { params: Vec<(String, Option<Type>)>, body: Box<Expr>, env: Environment, }, Option(Option<Box<Value>>), Unit, Break(Option<Box<Value>>), Continue, Return(Option<Box<Value>>),
}
A runtime value produced by evaluating an expression.

Every result of evaluation is represented as a Value. This includes primitive types (int, float, bool, char, string), compound types (array, tuple, struct), callable types (function, closure), and control-flow sentinels (break, continue, return).

Variants



Int(i64)



Float(f64)



Bool(bool)



Char(char)



String(String)



Array(Vec<Value>)



Tuple(Vec<Value>)



Struct

Fields

name: String


Function

Fields

name: String
params: Vec<(String, Type)>
body: Box<Expr>
closure_env: Option<Environment>


Closure

Fields

params: Vec<(String, Option<Type>)>
body: Box<Expr>


Option(Option<Box<Value>>)



Unit



Break(Option<Box<Value>>)

Signals a break with an optional value.



Continue

Signals a continue.



Return(Option<Box<Value>>)

Signals a return with an optional value.

Implementations

Source

impl Value

pub fn is_truthy(&self) -> bool

Returns true if the value is considered “truthy” in boolean context.

pub fn type_name(&self) -> &str

Returns the human-readable name of this value’s type.

pub fn debug_fmt(&self) -> String

Debug-style format that shows quotes around strings and chars.