Module token

Module token 

Token definitions for the Rust subset supported by VirtualRust.

Each token represents an atomic syntactic element produced by the lexer.

Enums

Token
All token types recognized by the lexer.