Token

Enum Token 

pub enum Token {
Show 90 variants IntLiteral(i64), FloatLiteral(f64), StringLiteral(String), CharLiteral(char), BoolLiteral(bool), Ident(String), Let, Mut, Fn, Return, If, Else, While, Loop, For, In, Break, Continue, Struct, Impl, Self_, Enum, Match, Pub, Use, Mod, As, Ref, I8, I16, I32, I64, I128, U8, U16, U32, U64, U128, F32, F64, Bool, Char, Str, String_, Usize, Isize, Plus, Minus, Star, Slash, Percent, Eq, EqEq, NotEq, Lt, LtEq, Gt, GtEq, And, Or, Not, Ampersand, Pipe, Caret, Tilde, Shl, Shr, PlusEq, MinusEq, StarEq, SlashEq, PercentEq, LParen, RParen, LBrace, RBrace, LBracket, RBracket, Comma, Semicolon, Colon, ColonColon, Arrow, FatArrow, Dot, DotDot, DotDotEq, Hash, Underscore, Eof,
}
All token types recognized by the lexer.

Variants



IntLiteral(i64)



FloatLiteral(f64)



StringLiteral(String)



CharLiteral(char)



BoolLiteral(bool)



Ident(String)



Let



Mut



Fn



Return



If



Else



While



Loop



For



In



Break



Continue



Struct



Impl



Self_



Enum



Match



Pub



Use



Mod



As



Ref



I8



I16



I32



I64



I128



U8



U16



U32



U64



U128



F32



F64



Bool



Char



Str



String_



Usize



Isize



Plus



Minus



Star



Slash



Percent



Eq



EqEq



NotEq



Lt



LtEq



Gt



GtEq



And



Or



Not



Ampersand



Pipe



Caret



Tilde



Shl



Shr



PlusEq



MinusEq



StarEq



SlashEq



PercentEq



LParen



RParen



LBrace



RBrace



LBracket



RBracket



Comma



Semicolon



Colon



ColonColon



Arrow



FatArrow



Dot



DotDot



DotDotEq



Hash



Underscore



Eof

Implementations

Source

impl Token

pub fn keyword_from_str(s: &str) -> Option<Token>

Returns the keyword Token for a given string, or None if not a keyword.